==> kadu_0.6.0.orig.tar.gz: kadu/modules/docking/translations/docking_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>@default</name>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="4"/>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="7"/>
        <source>Tray</source>
        <translation>Barra</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="10"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="13"/>
        <source>Start docked</source>
        <translation>Parti minimizzato</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="16"/>
        <source>Show tooltip in tray</source>
        <translation>Visualizza notifiche sulla barra</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="19"/>
        <source>New message tray icon</source>
        <translation>Icona del nuovo messaggio sulla barra</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="22"/>
        <source>Blinking envelope</source>
        <translation>Copertina lampeggiante</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="25"/>
        <source>Static envelope</source>
        <translation>Copertina statica</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="28"/>
        <source>Animated envelope</source>
        <translation>Copertina animata</translation>
    </message>
</context>
<context>
    <name>DockingManager</name>
    <message>
        <location filename="../docking.cpp" line="173"/>
        <source>

Current status:
%1</source>
        <translation>

Status attuale:
%1</translation>
    </message>
    <message>
        <location filename="../docking.cpp" line="176"/>
        <source>

Description:
%2</source>
        <translation>

Descrizione:
%2</translation>
    </message>
    <message>
        <location filename="../docking.cpp" line="171"/>
        <source>Left click - hide / show window
Middle click or Left click - open message</source>
        <translation>Tasto sx - mostra / nascondi finestra
Tasto centrale oppure sx - apri messaggio</translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.4.orig.tar.gz: kadu/modules/docking/translations/docking_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Barra</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Start docked</source>
        <translation>Parti minimizzato</translation>
    </message>
    <message>
        <source>Show tooltip in tray</source>
        <translation>Visualizza notifiche sulla barra</translation>
    </message>
    <message>
        <source>New message tray icon</source>
        <translation>Icona del nuovo messaggio sulla barra</translation>
    </message>
    <message>
        <source>Blinking envelope</source>
        <translation>Copertina lampeggiante</translation>
    </message>
    <message>
        <source>Static envelope</source>
        <translation>Copertina statica</translation>
    </message>
    <message>
        <source>Animated envelope</source>
        <translation>Copertina animata</translation>
    </message>
    <message>
        <source>No change</source>
        <translation>Non cambia</translation>
    </message>
</context>
<context>
    <name>DockingManager</name>
    <message>
        <source>

Description:
%2</source>
        <translation>

Descrizione:
%2</translation>
    </message>
    <message>
        <source>Current status:
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
